'use strict';

// CODELAB: Update cache names any time any of the cached files change.
const CACHE_NAME = 'offline-v2';

// CODELAB: Add list of files to cache here.
const FILES_TO_CACHE = [
    'weblib/pwaoffline'
];

self.addEventListener('install', (evt) => {
    // CODELAB: Precache static resources here.
    evt.waitUntil(
                  caches.open(CACHE_NAME).then((cache) => {
                      console.log('[ServiceWorker] Pre-caching offline page');
                      return cache.addAll(FILES_TO_CACHE);
                  })
    );
    self.skipWaiting();
});

self.addEventListener('activate', (evt) => {
  // CODELAB: Remove previous cached data from disk.
  evt.waitUntil(
                caches.keys().then((keyList) => {
                  return Promise.all(keyList.map((key) => {
                    if (key !== CACHE_NAME) {
                      console.log('[ServiceWorker] Removing old cache', key);
                      return caches.delete(key);
                    }
                  }));
                })
            );
  self.clients.claim();
});

self.addEventListener('fetch', (evt) => {
    // CODELAB: Add fetch event handler here.
    if (evt.request.mode !== 'navigate') {
      // Not a page navigation, bail.
      return;
    }
    // Ignore login requests, because of a bug in chrome with localhost
    if (evt.request.url.indexOf(self.location.origin + '/login') == 0) {
        return;
    }
    evt.respondWith(
        fetch(evt.request)
            .catch(() => {
              return caches.open(CACHE_NAME)
                  .then((cache) => {
                    return cache.match('weblib/pwaoffline');
                  });
            })
    );
});

self.addEventListener('notificationclick', (evt) => {
    evt.notification.close();
    if (evt.notification.data != undefined) {
        // Get all the Window clients
        evt.waitUntil(clients.matchAll({ type: 'window' }).then(clientsArr => {
            // If a Window tab matching the targeted URL already exists, focus that;
            const hadWindowToFocus = clientsArr.some(windowClient => windowClient.url === evt.notification.data ? (windowClient.focus && windowClient.focus(), true) : false);
            // Otherwise, open a new tab to the applicable URL and focus it.
            if (!hadWindowToFocus) clients.openWindow(evt.notification.data).then(windowClient => windowClient ? (windowClient.focus && windowClient.focus()) : null);
        }));
        
    }
});